@@ -30,7 +30,7 @@ import (
 type resetData interface {
 	ForceReset() bool
 	InputReader() io.Reader
-	IgnorePreflightErrors() sets.String
+	IgnorePreflightErrors() sets.Set[string]
 	Cfg() *kubeadmapi.InitConfiguration
 	DryRun() bool
 	Client() clientset.Interface
