@@ -16,7 +16,7 @@
 
 # This script genertates `*/api.pb.go` from the protobuf file `*/api.proto`.
 # Usage: 
-#     hack/update-generated-protobuf-dockerized.sh "${APIROOTS}"
+#     hack/update-generated-protobuf-dockerized.sh "${APIROOTS[@]}"
 #     An example APIROOT is: "k8s.io/api/admissionregistration/v1"
 
 set -o errexit
@@ -25,29 +25,16 @@ set -o pipefail
 
 KUBE_ROOT=$(dirname "${BASH_SOURCE[0]}")/..
 source "${KUBE_ROOT}/hack/lib/init.sh"
+source "${KUBE_ROOT}/hack/lib/protoc.sh"
 
+kube::protoc::check_protoc
 kube::golang::setup_env
 
 GO111MODULE=on GOPROXY=off go install k8s.io/code-generator/cmd/go-to-protobuf
 GO111MODULE=on GOPROXY=off go install k8s.io/code-generator/cmd/go-to-protobuf/protoc-gen-gogo
 
-if [[ -z "$(which protoc)" || "$(protoc --version)" != "libprotoc 23.4"* ]]; then
-	echo "Generating protobuf requires protoc 23.4 or newer. Please download and"
-    echo "install the platform appropriate Protobuf package for your OS: "
-    echo
-    echo "  https://github.com/protocolbuffers/protobuf/releases"
-    echo
-    echo "WARNING: Protobuf changes are not being validated"
-    exit 1
-fi
-
 gotoprotobuf=$(kube::util::find-binary "go-to-protobuf")
 
-while IFS=$'\n' read -r line; do
-  APIROOTS+=( "$line" );
-done <<< "${1}"
-shift
-
 # requires the 'proto' tag to build (will remove when ready)
 # searches for the protoc-gen-gogo extension in the output directory
 # satisfies import of github.com/gogo/protobuf/gogoproto/gogo.proto and the
@@ -56,6 +43,5 @@ PATH="${KUBE_ROOT}/_output/bin:${PATH}" \
   "${gotoprotobuf}" \
   --proto-import="${KUBE_ROOT}/vendor" \
   --proto-import="${KUBE_ROOT}/third_party/protobuf" \
-  --packages="$(IFS=, ; echo "${APIROOTS[*]}")" \
-  --go-header-file "${KUBE_ROOT}/hack/boilerplate/boilerplate.generatego.txt" \
-  "$@"
+  --packages="$(IFS=, ; echo "$*")" \
+  --go-header-file "${KUBE_ROOT}/hack/boilerplate/boilerplate.generatego.txt"
