@@ -47,12 +47,12 @@ trap cleanup EXIT SIGINT
 
 kube::golang::setup_env
 
-TMP_DIR=$(mktemp -d /tmp/update-openapi-spec.XXXX)
+TMP_DIR=${TMP_DIR:-$(kube::realpath "$(mktemp -d -t "$(basename "$0").XXXXXX")")}
 ETCD_HOST=${ETCD_HOST:-127.0.0.1}
 ETCD_PORT=${ETCD_PORT:-2379}
 API_PORT=${API_PORT:-8050}
 API_HOST=${API_HOST:-127.0.0.1}
-API_LOGFILE=${API_LOGFILE:-/tmp/openapi-api-server.log}
+API_LOGFILE=${API_LOGFILE:-${TMP_DIR}/openapi-api-server.log}
 
 kube::etcd::start
 
@@ -60,7 +60,7 @@ echo "dummy_token,admin,admin" > "${TMP_DIR}/tokenauth.csv"
 
 # setup envs for TokenRequest required flags
 SERVICE_ACCOUNT_LOOKUP=${SERVICE_ACCOUNT_LOOKUP:-true}
-SERVICE_ACCOUNT_KEY=${SERVICE_ACCOUNT_KEY:-/tmp/kube-serviceaccount.key}
+SERVICE_ACCOUNT_KEY=${SERVICE_ACCOUNT_KEY:-${TMP_DIR}/kube-serviceaccount.key}
 # Generate ServiceAccount key if needed
 if [[ ! -f "${SERVICE_ACCOUNT_KEY}" ]]; then
   mkdir -p "$(dirname "${SERVICE_ACCOUNT_KEY}")"
@@ -98,7 +98,11 @@ fi
 
 kube::log::status "Updating " "${OPENAPI_ROOT_DIR} for OpenAPI v2"
 
-curl -w "\n" -kfsS -H 'Authorization: Bearer dummy_token' "https://${API_HOST}:${API_PORT}/openapi/v2" | jq -S '.info.version="unversioned"' > "${OPENAPI_ROOT_DIR}/swagger.json"
+rm -f "${OPENAPI_ROOT_DIR}/swagger.json"
+curl -w "\n" -kfsS -H 'Authorization: Bearer dummy_token' \
+  "https://${API_HOST}:${API_PORT}/openapi/v2" \
+  | jq -S '.info.version="unversioned"' \
+  > "${OPENAPI_ROOT_DIR}/swagger.json"
 
 kube::log::status "Updating " "${OPENAPI_ROOT_DIR}/v3 for OpenAPI v3"
 
@@ -107,12 +111,19 @@ mkdir -p "${OPENAPI_ROOT_DIR}/v3"
 # ".well-known__openid-configuration_openapi.json"
 rm -r "${OPENAPI_ROOT_DIR}"/v3/{*,.*} || true
 
-curl -w "\n" -kfsS -H 'Authorization: Bearer dummy_token' "https://${API_HOST}:${API_PORT}/openapi/v3" | jq -r '.paths | to_entries | .[].key' | while read -r group; do
+rm -rf "${OPENAPI_ROOT_DIR}/v3/*"
+curl -w "\n" -kfsS -H 'Authorization: Bearer dummy_token' \
+  "https://${API_HOST}:${API_PORT}/openapi/v3" \
+  | jq -r '.paths | to_entries | .[].key' \
+  | while read -r group; do
     kube::log::status "Updating OpenAPI spec for group ${group}"
     OPENAPI_FILENAME="${group}_openapi.json"
     OPENAPI_FILENAME_ESCAPED="${OPENAPI_FILENAME//\//__}"
     OPENAPI_PATH="${OPENAPI_ROOT_DIR}/v3/${OPENAPI_FILENAME_ESCAPED}"
-    curl -w "\n" -kfsS -H 'Authorization: Bearer dummy_token' "https://${API_HOST}:${API_PORT}/openapi/v3/{$group}" | jq -S '.info.version="unversioned"' > "$OPENAPI_PATH"
+    curl -w "\n" -kfsS -H 'Authorization: Bearer dummy_token' \
+      "https://${API_HOST}:${API_PORT}/openapi/v3/{$group}" \
+      | jq -S '.info.version="unversioned"' \
+      > "$OPENAPI_PATH"
 done
 
 kube::log::status "SUCCESS"
