@@ -51,9 +51,8 @@ var GVRToStorageVersionHash = map[string]string{
 	"v1/secrets":                "S6u1pOWzb84=",
 	"v1/serviceaccounts":        "pbx9ZvyFpBE=",
 	"v1/services":               "0/CO1lhkEBI=",
-	"autoscaling/v1/horizontalpodautoscalers":      "oQlkt7f5j/A=",
-	"autoscaling/v2/horizontalpodautoscalers":      "oQlkt7f5j/A=",
-	"autoscaling/v2beta2/horizontalpodautoscalers": "oQlkt7f5j/A=",
+	"autoscaling/v1/horizontalpodautoscalers": "qwQve8ut294=",
+	"autoscaling/v2/horizontalpodautoscalers": "qwQve8ut294=",
 	"batch/v1/jobs":     "mudhfqk/qZY=",
 	"batch/v1/cronjobs": "sd5LIXh4Fjs=",
 	"certificates.k8s.io/v1/certificatesigningrequests":                "95fRKMXA+00=",
@@ -63,7 +62,7 @@ var GVRToStorageVersionHash = map[string]string{
 	"networking.k8s.io/v1/ingresses":                                   "39NQlfNR+bo=",
 	"networking.k8s.io/v1/ingressclasses":                              "l/iqIbDgFyQ=",
 	"node.k8s.io/v1/runtimeclasses":                                    "WQTu1GL3T2Q=",
-	"policy/v1/poddisruptionbudgets":                                   "6BGBu0kpHtk=",
+	"policy/v1/poddisruptionbudgets":                                   "EVWiDmWqyJw=",
 	"rbac.authorization.k8s.io/v1/clusterrolebindings":                 "48tpQ8gZHFc=",
 	"rbac.authorization.k8s.io/v1/clusterroles":                        "bYE5ZWDrJ44=",
 	"rbac.authorization.k8s.io/v1/rolebindings":                        "eGsCzGH6b1g=",
@@ -74,7 +73,6 @@ var GVRToStorageVersionHash = map[string]string{
 	"storage.k8s.io/v1/storageclasses":                                 "K+m6uJwbjGY=",
 	"storage.k8s.io/v1/csistoragecapacities":                           "xeVl+2Ly1kE=",
 	"storage.k8s.io/v1/volumeattachments":                              "tJx/ezt6UDU=",
-	"storage.k8s.io/v1beta1/csistoragecapacities":                      "xeVl+2Ly1kE=",
 	"apps/v1/controllerrevisions":                                      "85nkx63pcBU=",
 	"apps/v1/daemonsets":                                               "dd7pWHUlMKQ=",
 	"apps/v1/deployments":                                              "8aSe+NMegvE=",
@@ -83,10 +81,8 @@ var GVRToStorageVersionHash = map[string]string{
 	"admissionregistration.k8s.io/v1/mutatingwebhookconfigurations":    "Sqi0GUgDaX0=",
 	"admissionregistration.k8s.io/v1/validatingwebhookconfigurations":  "B0wHjQmsGNk=",
 	"events.k8s.io/v1/events":                                          "r2yiGXH7wu8=",
-	"flowcontrol.apiserver.k8s.io/v1beta3/flowschemas":                 "G+8IkrqFuJw=",
-	"flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations": "wltM4WMeeXs=",
-	"flowcontrol.apiserver.k8s.io/v1beta2/flowschemas":                 "G+8IkrqFuJw=",
-	"flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations": "wltM4WMeeXs=",
-	"flowcontrol.apiserver.k8s.io/v1beta1/flowschemas":                 "G+8IkrqFuJw=",
-	"flowcontrol.apiserver.k8s.io/v1beta1/prioritylevelconfigurations": "wltM4WMeeXs=",
+	"flowcontrol.apiserver.k8s.io/v1beta3/flowschemas":                 "9NnFrw7ZEmA=",
+	"flowcontrol.apiserver.k8s.io/v1beta3/prioritylevelconfigurations": "+CwSrEWTDhc=",
+	"flowcontrol.apiserver.k8s.io/v1beta2/flowschemas":                 "9NnFrw7ZEmA=",
+	"flowcontrol.apiserver.k8s.io/v1beta2/prioritylevelconfigurations": "+CwSrEWTDhc=",
 }
