@@ -37,6 +37,9 @@ func TestApplyFeatureGates(t *testing.T) {
 	}{
 		{
 			name: "Feature gates disabled",
+			features: map[featuregate.Feature]bool{
+				features.PodSchedulingReadiness: false,
+			},
 			wantConfig: &v1beta2.Plugins{
 				QueueSort: v1beta2.PluginSet{
 					Enabled: []v1beta2.Plugin{
@@ -51,6 +54,7 @@ func TestApplyFeatureGates(t *testing.T) {
 						{Name: names.PodTopologySpread},
 						{Name: names.InterPodAffinity},
 						{Name: names.VolumeBinding},
+						{Name: names.VolumeZone},
 						{Name: names.NodeAffinity},
 					},
 				},
@@ -84,6 +88,8 @@ func TestApplyFeatureGates(t *testing.T) {
 						{Name: names.PodTopologySpread},
 						{Name: names.TaintToleration},
 						{Name: names.NodeAffinity},
+						{Name: names.NodeResourcesFit},
+						{Name: names.NodeResourcesBalancedAllocation},
 					},
 				},
 				Score: v1beta2.PluginSet{
@@ -138,6 +144,7 @@ func TestApplyFeatureGates(t *testing.T) {
 						{Name: names.PodTopologySpread},
 						{Name: names.InterPodAffinity},
 						{Name: names.VolumeBinding},
+						{Name: names.VolumeZone},
 						{Name: names.NodeAffinity},
 					},
 				},
@@ -171,6 +178,8 @@ func TestApplyFeatureGates(t *testing.T) {
 						{Name: names.PodTopologySpread},
 						{Name: names.TaintToleration},
 						{Name: names.NodeAffinity},
+						{Name: names.NodeResourcesFit},
+						{Name: names.NodeResourcesBalancedAllocation},
 					},
 				},
 				Score: v1beta2.PluginSet{
