@@ -97,26 +97,26 @@ func Test_PVLAdmission(t *testing.T) {
 			handler:   newPersistentVolumeLabel(),
 			pvlabeler: mockVolumeFailure(errors.New("invalid volume")),
 			preAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{Name: "awsebs", Namespace: "myns"},
+				ObjectMeta: metav1.ObjectMeta{Name: "vSpherePV", Namespace: "myns"},
 				Spec: api.PersistentVolumeSpec{
 					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
+						VsphereVolume: &api.VsphereVirtualDiskVolumeSource{
+							VolumePath: "123",
 						},
 					},
 				},
 			},
 			postAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{Name: "awsebs", Namespace: "myns"},
+				ObjectMeta: metav1.ObjectMeta{Name: "vSpherePV", Namespace: "myns"},
 				Spec: api.PersistentVolumeSpec{
 					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
+						VsphereVolume: &api.VsphereVirtualDiskVolumeSource{
+							VolumePath: "123",
 						},
 					},
 				},
 			},
-			err: apierrors.NewForbidden(schema.ParseGroupResource("persistentvolumes"), "awsebs", errors.New("error querying AWS EBS volume 123: invalid volume")),
+			err: apierrors.NewForbidden(schema.ParseGroupResource("persistentvolumes"), "vSpherePV", errors.New("error querying vSphere Volume 123: invalid volume")),
 		},
 		{
 			name:      "cloud provider returns no labels",
@@ -170,69 +170,6 @@ func Test_PVLAdmission(t *testing.T) {
 			},
 			err: nil,
 		},
-		{
-			name:    "AWS EBS PV labeled correctly",
-			handler: newPersistentVolumeLabel(),
-			pvlabeler: mockVolumeLabels(map[string]string{
-				"a":                  "1",
-				"b":                  "2",
-				v1.LabelTopologyZone: "1__2__3",
-			}),
-			preAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{Name: "awsebs", Namespace: "myns"},
-				Spec: api.PersistentVolumeSpec{
-					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
-						},
-					},
-				},
-			},
-			postAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
-					Namespace: "myns",
-					Labels: map[string]string{
-						"a":                  "1",
-						"b":                  "2",
-						v1.LabelTopologyZone: "1__2__3",
-					},
-				},
-				Spec: api.PersistentVolumeSpec{
-					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
-						},
-					},
-					NodeAffinity: &api.VolumeNodeAffinity{
-						Required: &api.NodeSelector{
-							NodeSelectorTerms: []api.NodeSelectorTerm{
-								{
-									MatchExpressions: []api.NodeSelectorRequirement{
-										{
-											Key:      "a",
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"1"},
-										},
-										{
-											Key:      "b",
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"2"},
-										},
-										{
-											Key:      v1.LabelTopologyZone,
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"1", "2", "3"},
-										},
-									},
-								},
-							},
-						},
-					},
-				},
-			},
-			err: nil,
-		},
 		{
 			name:    "existing Beta labels from dynamic provisioning are not changed",
 			handler: newPersistentVolumeLabel(),
@@ -378,7 +315,7 @@ func Test_PVLAdmission(t *testing.T) {
 			}),
 			preAdmissionPV: &api.PersistentVolume{
 				ObjectMeta: metav1.ObjectMeta{
-					Name: "awsebs", Namespace: "myns",
+					Name: "vSpherePV", Namespace: "myns",
 					Labels: map[string]string{
 						v1.LabelTopologyZone:   "existingDomain",
 						v1.LabelTopologyRegion: "existingRegion",
@@ -386,15 +323,15 @@ func Test_PVLAdmission(t *testing.T) {
 				},
 				Spec: api.PersistentVolumeSpec{
 					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
+						VsphereVolume: &api.VsphereVirtualDiskVolumeSource{
+							VolumePath: "123",
 						},
 					},
 				},
 			},
 			postAdmissionPV: &api.PersistentVolume{
 				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
+					Name:      "vSpherePV",
 					Namespace: "myns",
 					Labels: map[string]string{
 						v1.LabelTopologyZone:   "domain1",
@@ -403,8 +340,8 @@ func Test_PVLAdmission(t *testing.T) {
 				},
 				Spec: api.PersistentVolumeSpec{
 					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
+						VsphereVolume: &api.VsphereVirtualDiskVolumeSource{
+							VolumePath: "123",
 						},
 					},
 					NodeAffinity: &api.VolumeNodeAffinity{
@@ -561,150 +498,7 @@ func Test_PVLAdmission(t *testing.T) {
 			err: nil,
 		},
 		{
-			name:    "AWS EBS PV overrides user applied labels",
-			handler: newPersistentVolumeLabel(),
-			pvlabeler: mockVolumeLabels(map[string]string{
-				"a":                  "1",
-				"b":                  "2",
-				v1.LabelTopologyZone: "1__2__3",
-			}),
-			preAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
-					Namespace: "myns",
-					Labels: map[string]string{
-						"a": "not1",
-					},
-				},
-				Spec: api.PersistentVolumeSpec{
-					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
-						},
-					},
-				},
-			},
-			postAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
-					Namespace: "myns",
-					Labels: map[string]string{
-						"a":                  "1",
-						"b":                  "2",
-						v1.LabelTopologyZone: "1__2__3",
-					},
-				},
-				Spec: api.PersistentVolumeSpec{
-					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
-						},
-					},
-					NodeAffinity: &api.VolumeNodeAffinity{
-						Required: &api.NodeSelector{
-							NodeSelectorTerms: []api.NodeSelectorTerm{
-								{
-									MatchExpressions: []api.NodeSelectorRequirement{
-										{
-											Key:      "a",
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"1"},
-										},
-										{
-											Key:      "b",
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"2"},
-										},
-										{
-											Key:      v1.LabelTopologyZone,
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"1", "2", "3"},
-										},
-									},
-								},
-							},
-						},
-					},
-				},
-			},
-			err: nil,
-		},
-		{
-			name:    "AWS EBS PV conflicting affinity rules left in-tact",
-			handler: newPersistentVolumeLabel(),
-			pvlabeler: mockVolumeLabels(map[string]string{
-				"a": "1",
-				"b": "2",
-				"c": "3",
-			}),
-			preAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
-					Namespace: "myns",
-					Labels: map[string]string{
-						"c": "3",
-					},
-				},
-				Spec: api.PersistentVolumeSpec{
-					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
-						},
-					},
-					NodeAffinity: &api.VolumeNodeAffinity{
-						Required: &api.NodeSelector{
-							NodeSelectorTerms: []api.NodeSelectorTerm{
-								{
-									MatchExpressions: []api.NodeSelectorRequirement{
-										{
-											Key:      "c",
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"3"},
-										},
-									},
-								},
-							},
-						},
-					},
-				},
-			},
-			postAdmissionPV: &api.PersistentVolume{
-				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
-					Namespace: "myns",
-					Labels: map[string]string{
-						"a": "1",
-						"b": "2",
-						"c": "3",
-					},
-				},
-				Spec: api.PersistentVolumeSpec{
-					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
-						},
-					},
-					NodeAffinity: &api.VolumeNodeAffinity{
-						Required: &api.NodeSelector{
-							NodeSelectorTerms: []api.NodeSelectorTerm{
-								{
-									MatchExpressions: []api.NodeSelectorRequirement{
-										{
-											Key:      "c",
-											Operator: api.NodeSelectorOpIn,
-											Values:   []string{"3"},
-										},
-									},
-								},
-							},
-						},
-					},
-				},
-			},
-			err: nil,
-		},
-		{
-			name:    "AWS EBS PV non-conflicting affinity rules added",
+			name:    "vSphere PV non-conflicting affinity rules added",
 			handler: newPersistentVolumeLabel(),
 			pvlabeler: mockVolumeLabels(map[string]string{
 				"d": "1",
@@ -713,7 +507,7 @@ func Test_PVLAdmission(t *testing.T) {
 			}),
 			preAdmissionPV: &api.PersistentVolume{
 				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
+					Name:      "vSpherePV",
 					Namespace: "myns",
 					Labels: map[string]string{
 						"a": "1",
@@ -723,8 +517,8 @@ func Test_PVLAdmission(t *testing.T) {
 				},
 				Spec: api.PersistentVolumeSpec{
 					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
+						VsphereVolume: &api.VsphereVirtualDiskVolumeSource{
+							VolumePath: "123",
 						},
 					},
 					NodeAffinity: &api.VolumeNodeAffinity{
@@ -756,7 +550,7 @@ func Test_PVLAdmission(t *testing.T) {
 			},
 			postAdmissionPV: &api.PersistentVolume{
 				ObjectMeta: metav1.ObjectMeta{
-					Name:      "awsebs",
+					Name:      "vSpherePV",
 					Namespace: "myns",
 					Labels: map[string]string{
 						"a": "1",
@@ -769,8 +563,8 @@ func Test_PVLAdmission(t *testing.T) {
 				},
 				Spec: api.PersistentVolumeSpec{
 					PersistentVolumeSource: api.PersistentVolumeSource{
-						AWSElasticBlockStore: &api.AWSElasticBlockStoreVolumeSource{
-							VolumeID: "123",
+						VsphereVolume: &api.VsphereVirtualDiskVolumeSource{
+							VolumePath: "123",
 						},
 					},
 					NodeAffinity: &api.VolumeNodeAffinity{
@@ -914,7 +708,6 @@ func Test_PVLAdmission(t *testing.T) {
 // provider does not reduce test coverage but it does simplify/clean up the tests here because
 // the provider is then decided based on the type of PV (EBS, GCEPD, Azure Disk, etc)
 func setPVLabeler(handler *persistentVolumeLabel, pvlabeler cloudprovider.PVLabeler) {
-	handler.awsPVLabeler = pvlabeler
 	handler.gcePVLabeler = pvlabeler
 	handler.azurePVLabeler = pvlabeler
 	handler.vspherePVLabeler = pvlabeler
