@@ -17,7 +17,6 @@ limitations under the License.
 package options
 
 import (
-	"io/ioutil"
 	"os"
 	"reflect"
 	"testing"
@@ -185,12 +184,12 @@ controllerLeaders:
 		t.Run(tc.name, func(t *testing.T) {
 			flags := tc.flags
 			if tc.configContent != "" {
-				configFile, err := ioutil.TempFile("", tc.name)
+				configFile, err := os.CreateTemp("", tc.name)
 				if err != nil {
 					t.Fatal(err)
 				}
 				defer os.Remove(configFile.Name())
-				err = ioutil.WriteFile(configFile.Name(), []byte(tc.configContent), os.FileMode(0755))
+				err = os.WriteFile(configFile.Name(), []byte(tc.configContent), os.FileMode(0755))
 				if err != nil {
 					t.Fatal(err)
 				}
