@@ -57,7 +57,6 @@ type GetOptions struct {
 	PrintFlags             *PrintFlags
 	ToPrinter              func(*meta.RESTMapping, *bool, bool, bool) (printers.ResourcePrinterFunc, error)
 	IsHumanReadablePrinter bool
-	PrintWithOpenAPICols   bool
 
 	CmdParent string
 
@@ -76,11 +75,11 @@ type GetOptions struct {
 	Namespace         string
 	ExplicitNamespace bool
 	Subresource       string
+	SortBy            string
 
 	ServerPrint bool
 
 	NoHeaders      bool
-	Sort           bool
 	IgnoreNotFound bool
 
 	genericclioptions.IOStreams
@@ -137,8 +136,7 @@ var (
 )
 
 const (
-	useOpenAPIPrintColumnFlagLabel = "use-openapi-print-columns"
-	useServerPrintColumns          = "server-print"
+	useServerPrintColumns = "server-print"
 )
 
 var supportedSubresources = []string{"status", "scale"}
@@ -170,7 +168,7 @@ func NewCmdGet(parent string, f cmdutil.Factory, streams genericclioptions.IOStr
 		Run: func(cmd *cobra.Command, args []string) {
 			cmdutil.CheckErr(o.Complete(f, cmd, args))
 			cmdutil.CheckErr(o.Validate())
-			cmdutil.CheckErr(o.Run(f, cmd, args))
+			cmdutil.CheckErr(o.Run(f, args))
 		},
 		SuggestFor: []string{"list", "ps"},
 	}
@@ -184,7 +182,6 @@ func NewCmdGet(parent string, f cmdutil.Factory, streams genericclioptions.IOStr
 	cmd.Flags().BoolVar(&o.IgnoreNotFound, "ignore-not-found", o.IgnoreNotFound, "If the requested object does not exist the command will return exit code 0.")
 	cmd.Flags().StringVar(&o.FieldSelector, "field-selector", o.FieldSelector, "Selector (field query) to filter on, supports '=', '==', and '!='.(e.g. --field-selector key1=value1,key2=value2). The server only supports a limited number of field queries per type.")
 	cmd.Flags().BoolVarP(&o.AllNamespaces, "all-namespaces", "A", o.AllNamespaces, "If present, list the requested object(s) across all namespaces. Namespace in current context is ignored even if specified with --namespace.")
-	addOpenAPIPrintColumnFlags(cmd, o)
 	addServerPrintColumnFlags(cmd, o)
 	cmdutil.AddFilenameOptionFlags(cmd, &o.FilenameOptions, "identifying the resource to get from a server.")
 	cmdutil.AddChunkSizeFlag(cmd, &o.ChunkSize)
@@ -211,11 +208,9 @@ func (o *GetOptions) Complete(f cmdutil.Factory, cmd *cobra.Command, args []stri
 		o.ExplicitNamespace = false
 	}
 
-	sortBy, err := cmd.Flags().GetString("sort-by")
-	if err != nil {
-		return err
+	if o.PrintFlags.HumanReadableFlags.SortBy != nil {
+		o.SortBy = *o.PrintFlags.HumanReadableFlags.SortBy
 	}
-	o.Sort = len(sortBy) > 0
 
 	o.NoHeaders = cmdutil.GetFlagBool(cmd, "no-headers")
 
@@ -241,11 +236,6 @@ func (o *GetOptions) Complete(f cmdutil.Factory, cmd *cobra.Command, args []stri
 		printFlags := o.PrintFlags.Copy()
 
 		if mapping != nil {
-			if !cmdSpecifiesOutputFmt(cmd) && o.PrintWithOpenAPICols {
-				if apiSchema, err := f.OpenAPISchema(); err == nil {
-					printFlags.UseOpenAPIColumns(apiSchema, mapping)
-				}
-			}
 			printFlags.SetKind(mapping.GroupVersionKind.GroupKind())
 		}
 		if withNamespace {
@@ -264,8 +254,8 @@ func (o *GetOptions) Complete(f cmdutil.Factory, cmd *cobra.Command, args []stri
 			return nil, err
 		}
 
-		if o.Sort {
-			printer = &SortingPrinter{Delegate: printer, SortField: sortBy}
+		if len(o.SortBy) > 0 {
+			printer = &SortingPrinter{Delegate: printer, SortField: o.SortBy}
 		}
 		if outputObjects != nil {
 			printer = &skipPrinter{delegate: printer, output: outputObjects}
@@ -278,7 +268,7 @@ func (o *GetOptions) Complete(f cmdutil.Factory, cmd *cobra.Command, args []stri
 
 	switch {
 	case o.Watch || o.WatchOnly:
-		if o.Sort {
+		if len(o.SortBy) > 0 {
 			fmt.Fprintf(o.IOStreams.ErrOut, "warning: --watch or --watch-only requested, --sort-by will be ignored\n")
 		}
 	default:
@@ -294,11 +284,6 @@ func (o *GetOptions) Complete(f cmdutil.Factory, cmd *cobra.Command, args []stri
 		}
 	}
 
-	// openapi printing is mutually exclusive with server side printing
-	if o.PrintWithOpenAPICols && o.ServerPrint {
-		fmt.Fprintf(o.IOStreams.ErrOut, "warning: --%s requested, --%s will be ignored\n", useOpenAPIPrintColumnFlagLabel, useServerPrintColumns)
-	}
-
 	return nil
 }
 
@@ -433,10 +418,6 @@ func NewRuntimeSorter(objects []runtime.Object, sortBy string) *RuntimeSorter {
 }
 
 func (o *GetOptions) transformRequests(req *rest.Request) {
-	// We need full objects if printing with openapi columns
-	if o.PrintWithOpenAPICols {
-		return
-	}
 	if !o.ServerPrint || !o.IsHumanReadablePrinter {
 		return
 	}
@@ -448,14 +429,14 @@ func (o *GetOptions) transformRequests(req *rest.Request) {
 	}, ","))
 
 	// if sorting, ensure we receive the full object in order to introspect its fields via jsonpath
-	if o.Sort {
+	if len(o.SortBy) > 0 {
 		req.Param("includeObject", "Object")
 	}
 }
 
 // Run performs the get operation.
 // TODO: remove the need to pass these arguments, like other commands.
-func (o *GetOptions) Run(f cmdutil.Factory, cmd *cobra.Command, args []string) error {
+func (o *GetOptions) Run(f cmdutil.Factory, args []string) error {
 	if len(o.Raw) > 0 {
 		restClient, err := f.RESTClient()
 		if err != nil {
@@ -464,11 +445,11 @@ func (o *GetOptions) Run(f cmdutil.Factory, cmd *cobra.Command, args []string) e
 		return rawhttp.RawGet(restClient, o.IOStreams, o.Raw)
 	}
 	if o.Watch || o.WatchOnly {
-		return o.watch(f, cmd, args)
+		return o.watch(f, args)
 	}
 
 	chunkSize := o.ChunkSize
-	if o.Sort {
+	if len(o.SortBy) > 0 {
 		// TODO(juanvallejo): in the future, we could have the client use chunking
 		// to gather all results, then sort them all at the end to reduce server load.
 		chunkSize = 0
@@ -513,14 +494,9 @@ func (o *GetOptions) Run(f cmdutil.Factory, cmd *cobra.Command, args []string) e
 		objs[ix] = infos[ix].Object
 	}
 
-	sorting, err := cmd.Flags().GetString("sort-by")
-	if err != nil {
-		return err
-	}
-
 	var positioner OriginalPositioner
-	if o.Sort {
-		sorter := NewRuntimeSorter(objs, sorting)
+	if len(o.SortBy) > 0 {
+		sorter := NewRuntimeSorter(objs, o.SortBy)
 		if err := sorter.Sort(); err != nil {
 			return err
 		}
@@ -580,13 +556,6 @@ func (o *GetOptions) Run(f cmdutil.Factory, cmd *cobra.Command, args []string) e
 			lastMapping = mapping
 		}
 
-		// ensure a versioned object is passed to the custom-columns printer
-		// if we are using OpenAPI columns to print
-		if o.PrintWithOpenAPICols {
-			printer.PrintObj(info.Object, w)
-			continue
-		}
-
 		printer.PrintObj(info.Object, w)
 	}
 	w.Flush()
@@ -632,7 +601,7 @@ func (s *separatorWriterWrapper) SetReady(state bool) {
 
 // watch starts a client-side watch of one or more resources.
 // TODO: remove the need for arguments here.
-func (o *GetOptions) watch(f cmdutil.Factory, cmd *cobra.Command, args []string) error {
+func (o *GetOptions) watch(f cmdutil.Factory, args []string) error {
 	r := f.NewBuilder().
 		Unstructured().
 		NamespaceParam(o.Namespace).DefaultNamespace().AllNamespaces(o.AllNamespaces).
@@ -830,11 +799,6 @@ func (o *GetOptions) printGeneric(r *resource.Result) error {
 	return utilerrors.Reduce(utilerrors.Flatten(utilerrors.NewAggregate(errs)))
 }
 
-func addOpenAPIPrintColumnFlags(cmd *cobra.Command, opt *GetOptions) {
-	cmd.Flags().BoolVar(&opt.PrintWithOpenAPICols, useOpenAPIPrintColumnFlagLabel, opt.PrintWithOpenAPICols, "If true, use x-kubernetes-print-column metadata (if present) from the OpenAPI schema for displaying a resource.")
-	cmd.Flags().MarkDeprecated(useOpenAPIPrintColumnFlagLabel, "deprecated in favor of server-side printing")
-}
-
 func addServerPrintColumnFlags(cmd *cobra.Command, opt *GetOptions) {
 	cmd.Flags().BoolVar(&opt.ServerPrint, useServerPrintColumns, opt.ServerPrint, "If true, have the server return the appropriate table output. Supports extension APIs and CRDs.")
 }
@@ -843,10 +807,6 @@ func shouldGetNewPrinterForMapping(printer printers.ResourcePrinter, lastMapping
 	return printer == nil || lastMapping == nil || mapping == nil || mapping.Resource != lastMapping.Resource
 }
 
-func cmdSpecifiesOutputFmt(cmd *cobra.Command) bool {
-	return cmdutil.GetFlagString(cmd, "output") != ""
-}
-
 func multipleGVKsRequested(infos []*resource.Info) bool {
 	if len(infos) < 2 {
 		return false
