@@ -68,8 +68,7 @@ type EditOptions struct {
 	WindowsLineEndings bool
 
 	cmdutil.ValidateOptions
-	ValidationDirective     string
-	FieldValidationVerifier *resource.QueryParamVerifier
+	ValidationDirective string
 
 	OriginalResult *resource.Result
 
@@ -217,12 +216,6 @@ func (o *EditOptions) Complete(f cmdutil.Factory, args []string, cmd *cobra.Comm
 		return o.PrintFlags.ToPrinter()
 	}
 
-	dynamicClient, err := f.DynamicClient()
-	if err != nil {
-		return err
-	}
-	o.FieldValidationVerifier = resource.NewQueryParamVerifier(dynamicClient, f.OpenAPIGetter(), resource.QueryParamFieldValidation)
-
 	o.ValidationDirective, err = cmdutil.GetValidationDirective(cmd)
 	if err != nil {
 		return err
@@ -322,7 +315,7 @@ func (o *EditOptions) Run() error {
 			klog.V(4).Infof("User edited:\n%s", string(edited))
 
 			// Apply validation
-			schema, err := o.f.Validator(o.ValidationDirective, o.FieldValidationVerifier)
+			schema, err := o.f.Validator(o.ValidationDirective)
 			if err != nil {
 				return preservedFile(err, file, o.ErrOut)
 			}
