@@ -17,6 +17,7 @@ limitations under the License.
 package node
 
 import (
+	"context"
 	"time"
 
 	"k8s.io/apimachinery/pkg/util/wait"
@@ -25,7 +26,7 @@ import (
 )
 
 // WaitForSSHTunnels waits for establishing SSH tunnel to busybox pod.
-func WaitForSSHTunnels(namespace string) {
+func WaitForSSHTunnels(ctx context.Context, namespace string) {
 	framework.Logf("Waiting for SSH tunnels to establish")
 	e2ekubectl.RunKubectl(namespace, "run", "ssh-tunnel-test",
 		"--image=busybox",
@@ -35,7 +36,7 @@ func WaitForSSHTunnels(namespace string) {
 	defer e2ekubectl.RunKubectl(namespace, "delete", "pod", "ssh-tunnel-test")
 
 	// allow up to a minute for new ssh tunnels to establish
-	wait.PollImmediate(5*time.Second, time.Minute, func() (bool, error) {
+	wait.PollImmediateWithContext(ctx, 5*time.Second, time.Minute, func(ctx context.Context) (bool, error) {
 		_, err := e2ekubectl.RunKubectl(namespace, "logs", "ssh-tunnel-test")
 		return err == nil, nil
 	})
