@@ -38,12 +38,14 @@ import (
 	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/apimachinery/pkg/watch"
 	v1core "k8s.io/client-go/kubernetes/typed/core/v1"
+	"k8s.io/client-go/util/retry"
 	"k8s.io/kubernetes/pkg/kubelet/events"
 	"k8s.io/kubernetes/test/e2e/framework"
 	e2ekubelet "k8s.io/kubernetes/test/e2e/framework/kubelet"
 	e2epod "k8s.io/kubernetes/test/e2e/framework/pod"
 	imageutils "k8s.io/kubernetes/test/utils/image"
 	admissionapi "k8s.io/pod-security-admission/api"
+	utilpointer "k8s.io/utils/pointer"
 
 	"github.com/onsi/ginkgo/v2"
 	"github.com/prometheus/client_golang/prometheus"
@@ -65,7 +67,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 			Testname: Pods, delete grace period
 			Description: Create a pod, make sure it is running. Using the http client send a 'delete' with gracePeriodSeconds=30. Pod SHOULD get terminated within gracePeriodSeconds and removed from API server within a window.
 		*/
-		ginkgo.It("should be submitted and removed", func() {
+		ginkgo.It("should be submitted and removed", func(ctx context.Context) {
 			ginkgo.By("creating the pod")
 			name := "pod-submit-remove-" + string(uuid.NewUUID())
 			value := strconv.Itoa(time.Now().Nanosecond())
@@ -78,31 +80,31 @@ var _ = SIGDescribe("Pods Extended", func() {
 			ginkgo.By("setting up selector")
 			selector := labels.SelectorFromSet(labels.Set(map[string]string{"time": value}))
 			options := metav1.ListOptions{LabelSelector: selector.String()}
-			pods, err := podClient.List(context.TODO(), options)
+			pods, err := podClient.List(ctx, options)
 			framework.ExpectNoError(err, "failed to query for pod")
 			framework.ExpectEqual(len(pods.Items), 0)
 
 			ginkgo.By("submitting the pod to kubernetes")
-			podClient.Create(pod)
+			podClient.Create(ctx, pod)
 
 			ginkgo.By("verifying the pod is in kubernetes")
 			selector = labels.SelectorFromSet(labels.Set(map[string]string{"time": value}))
 			options = metav1.ListOptions{LabelSelector: selector.String()}
-			pods, err = podClient.List(context.TODO(), options)
+			pods, err = podClient.List(ctx, options)
 			framework.ExpectNoError(err, "failed to query for pod")
 			framework.ExpectEqual(len(pods.Items), 1)
 
 			// We need to wait for the pod to be running, otherwise the deletion
 			// may be carried out immediately rather than gracefully.
-			framework.ExpectNoError(e2epod.WaitForPodNameRunningInNamespace(f.ClientSet, pod.Name, f.Namespace.Name))
+			framework.ExpectNoError(e2epod.WaitForPodNameRunningInNamespace(ctx, f.ClientSet, pod.Name, f.Namespace.Name))
 			// save the running pod
-			pod, err = podClient.Get(context.TODO(), pod.Name, metav1.GetOptions{})
+			pod, err = podClient.Get(ctx, pod.Name, metav1.GetOptions{})
 			framework.ExpectNoError(err, "failed to GET scheduled pod")
 
 			ginkgo.By("deleting the pod gracefully")
 			var lastPod v1.Pod
 			var statusCode int
-			err = f.ClientSet.CoreV1().RESTClient().Delete().AbsPath("/api/v1/namespaces", pod.Namespace, "pods", pod.Name).Param("gracePeriodSeconds", "30").Do(context.TODO()).StatusCode(&statusCode).Into(&lastPod)
+			err = f.ClientSet.CoreV1().RESTClient().Delete().AbsPath("/api/v1/namespaces", pod.Namespace, "pods", pod.Name).Param("gracePeriodSeconds", "30").Do(ctx).StatusCode(&statusCode).Into(&lastPod)
 			framework.ExpectNoError(err, "failed to use http client to send delete")
 			framework.ExpectEqual(statusCode, http.StatusOK, "failed to delete gracefully by client request")
 
@@ -113,7 +115,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 			// latency between termination and reportal can be isolated further.
 			start := time.Now()
 			err = wait.Poll(time.Second*5, time.Second*30*3, func() (bool, error) {
-				podList, err := e2ekubelet.GetKubeletPods(f.ClientSet, pod.Spec.NodeName)
+				podList, err := e2ekubelet.GetKubeletPods(ctx, f.ClientSet, pod.Spec.NodeName)
 				if err != nil {
 					framework.Logf("Unable to retrieve kubelet pods for node %v: %v", pod.Spec.NodeName, err)
 					return false, nil
@@ -140,7 +142,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 
 			selector = labels.SelectorFromSet(labels.Set(map[string]string{"time": value}))
 			options = metav1.ListOptions{LabelSelector: selector.String()}
-			pods, err = podClient.List(context.TODO(), options)
+			pods, err = podClient.List(ctx, options)
 			framework.ExpectNoError(err, "failed to query for pods")
 			framework.ExpectEqual(len(pods.Items), 0)
 
@@ -158,7 +160,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 			Testname: Pods, QOS
 			Description:  Create a Pod with CPU and Memory request and limits. Pod status MUST have QOSClass set to PodQOSGuaranteed.
 		*/
-		framework.ConformanceIt("should be set on Pods with matching resource requests and limits for memory and cpu", func() {
+		framework.ConformanceIt("should be set on Pods with matching resource requests and limits for memory and cpu", func(ctx context.Context) {
 			ginkgo.By("creating the pod")
 			name := "pod-qos-class-" + string(uuid.NewUUID())
 			pod := &v1.Pod{
@@ -190,10 +192,10 @@ var _ = SIGDescribe("Pods Extended", func() {
 			}
 
 			ginkgo.By("submitting the pod to kubernetes")
-			podClient.Create(pod)
+			podClient.Create(ctx, pod)
 
 			ginkgo.By("verifying QOS class is set on the pod")
-			pod, err := podClient.Get(context.TODO(), name, metav1.GetOptions{})
+			pod, err := podClient.Get(ctx, name, metav1.GetOptions{})
 			framework.ExpectNoError(err, "failed to query for pod")
 			framework.ExpectEqual(pod.Status.QOSClass, v1.PodQOSGuaranteed)
 		})
@@ -205,17 +207,17 @@ var _ = SIGDescribe("Pods Extended", func() {
 			podClient = e2epod.NewPodClient(f)
 		})
 
-		ginkgo.It("should never report success for a pending container", func() {
+		ginkgo.It("should never report success for a pending container", func(ctx context.Context) {
 			ginkgo.By("creating pods that should always exit 1 and terminating the pod after a random delay")
-			createAndTestPodRepeatedly(
+			createAndTestPodRepeatedly(ctx,
 				3, 15,
 				podFastDeleteScenario{client: podClient.PodInterface, delayMs: 2000},
 				podClient.PodInterface,
 			)
 		})
-		ginkgo.It("should never report container start when an init container fails", func() {
+		ginkgo.It("should never report container start when an init container fails", func(ctx context.Context) {
 			ginkgo.By("creating pods with an init container that always exit 1 and terminating the pod after a random delay")
-			createAndTestPodRepeatedly(
+			createAndTestPodRepeatedly(ctx,
 				3, 15,
 				podFastDeleteScenario{client: podClient.PodInterface, delayMs: 2000, initContainer: true},
 				podClient.PodInterface,
@@ -229,7 +231,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 			podClient = e2epod.NewPodClient(f)
 		})
 
-		ginkgo.It("should not create extra sandbox if all containers are done", func() {
+		ginkgo.It("should not create extra sandbox if all containers are done", func(ctx context.Context) {
 			ginkgo.By("creating the pod that should always exit 0")
 
 			name := "pod-always-succeed" + string(uuid.NewUUID())
@@ -262,13 +264,13 @@ var _ = SIGDescribe("Pods Extended", func() {
 			}
 
 			ginkgo.By("submitting the pod to kubernetes")
-			createdPod := podClient.Create(pod)
-			defer func() {
+			createdPod := podClient.Create(ctx, pod)
+			ginkgo.DeferCleanup(func(ctx context.Context) error {
 				ginkgo.By("deleting the pod")
-				podClient.Delete(context.TODO(), pod.Name, metav1.DeleteOptions{})
-			}()
+				return podClient.Delete(ctx, pod.Name, metav1.DeleteOptions{})
+			})
 
-			framework.ExpectNoError(e2epod.WaitForPodSuccessInNamespace(f.ClientSet, pod.Name, f.Namespace.Name))
+			framework.ExpectNoError(e2epod.WaitForPodSuccessInNamespace(ctx, f.ClientSet, pod.Name, f.Namespace.Name))
 
 			var eventList *v1.EventList
 			var err error
@@ -281,7 +283,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 					"source":                   "kubelet",
 				}.AsSelector().String()
 				options := metav1.ListOptions{FieldSelector: selector}
-				eventList, err = f.ClientSet.CoreV1().Events(f.Namespace.Name).List(context.TODO(), options)
+				eventList, err = f.ClientSet.CoreV1().Events(f.Namespace.Name).List(ctx, options)
 				if err != nil {
 					return false, err
 				}
@@ -299,7 +301,7 @@ var _ = SIGDescribe("Pods Extended", func() {
 			}
 		})
 
-		ginkgo.It("evicted pods should be terminal", func() {
+		ginkgo.It("evicted pods should be terminal", func(ctx context.Context) {
 			ginkgo.By("creating the pod that should be evicted")
 
 			name := "pod-should-be-evicted" + string(uuid.NewUUID())
@@ -327,13 +329,13 @@ var _ = SIGDescribe("Pods Extended", func() {
 			}
 
 			ginkgo.By("submitting the pod to kubernetes")
-			podClient.Create(pod)
-			defer func() {
+			podClient.Create(ctx, pod)
+			ginkgo.DeferCleanup(func(ctx context.Context) error {
 				ginkgo.By("deleting the pod")
-				podClient.Delete(context.TODO(), pod.Name, metav1.DeleteOptions{})
-			}()
+				return podClient.Delete(ctx, pod.Name, metav1.DeleteOptions{})
+			})
 
-			err := e2epod.WaitForPodTerminatedInNamespace(f.ClientSet, pod.Name, "Evicted", f.Namespace.Name)
+			err := e2epod.WaitForPodTerminatedInNamespace(ctx, f.ClientSet, pod.Name, "Evicted", f.Namespace.Name)
 			if err != nil {
 				framework.Failf("error waiting for pod to be evicted: %v", err)
 			}
@@ -341,9 +343,81 @@ var _ = SIGDescribe("Pods Extended", func() {
 		})
 	})
 
+	ginkgo.Describe("Pod TerminationGracePeriodSeconds is negative", func() {
+		var podClient *e2epod.PodClient
+		ginkgo.BeforeEach(func() {
+			podClient = e2epod.NewPodClient(f)
+		})
+
+		ginkgo.It("pod with negative grace period", func(ctx context.Context) {
+			name := "pod-negative-grace-period" + string(uuid.NewUUID())
+			image := imageutils.GetE2EImage(imageutils.BusyBox)
+			pod := &v1.Pod{
+				ObjectMeta: metav1.ObjectMeta{
+					Name: name,
+				},
+				Spec: v1.PodSpec{
+					RestartPolicy: v1.RestartPolicyOnFailure,
+					Containers: []v1.Container{
+						{
+							Name:  "foo",
+							Image: image,
+							Command: []string{
+								"/bin/sh", "-c", "sleep 10000",
+							},
+						},
+					},
+					TerminationGracePeriodSeconds: utilpointer.Int64(-1),
+				},
+			}
+
+			ginkgo.By("submitting the pod to kubernetes")
+			podClient.Create(ctx, pod)
+
+			pod, err := podClient.Get(ctx, pod.Name, metav1.GetOptions{})
+			framework.ExpectNoError(err, "failed to query for pod")
+
+			if pod.Spec.TerminationGracePeriodSeconds == nil {
+				framework.Failf("pod spec TerminationGracePeriodSeconds is nil")
+			}
+
+			if *pod.Spec.TerminationGracePeriodSeconds != 1 {
+				framework.Failf("pod spec TerminationGracePeriodSeconds is not 1: %d", *pod.Spec.TerminationGracePeriodSeconds)
+			}
+
+			// retry if the TerminationGracePeriodSeconds is overrided
+			// see more in https://github.com/kubernetes/kubernetes/pull/115606
+			err = retry.RetryOnConflict(retry.DefaultBackoff, func() error {
+				pod, err := podClient.Get(ctx, pod.Name, metav1.GetOptions{})
+				framework.ExpectNoError(err, "failed to query for pod")
+				ginkgo.By("updating the pod to have a negative TerminationGracePeriodSeconds")
+				pod.Spec.TerminationGracePeriodSeconds = utilpointer.Int64(-1)
+				_, err = podClient.PodInterface.Update(ctx, pod, metav1.UpdateOptions{})
+				return err
+			})
+			framework.ExpectNoError(err, "failed to update pod")
+
+			pod, err = podClient.Get(ctx, pod.Name, metav1.GetOptions{})
+			framework.ExpectNoError(err, "failed to query for pod")
+
+			if pod.Spec.TerminationGracePeriodSeconds == nil {
+				framework.Failf("pod spec TerminationGracePeriodSeconds is nil")
+			}
+
+			if *pod.Spec.TerminationGracePeriodSeconds != 1 {
+				framework.Failf("pod spec TerminationGracePeriodSeconds is not 1: %d", *pod.Spec.TerminationGracePeriodSeconds)
+			}
+
+			ginkgo.DeferCleanup(func(ctx context.Context) error {
+				ginkgo.By("deleting the pod")
+				return podClient.Delete(ctx, pod.Name, metav1.DeleteOptions{})
+			})
+		})
+	})
+
 })
 
-func createAndTestPodRepeatedly(workers, iterations int, scenario podScenario, podClient v1core.PodInterface) {
+func createAndTestPodRepeatedly(ctx context.Context, workers, iterations int, scenario podScenario, podClient v1core.PodInterface) {
 	var (
 		lock sync.Mutex
 		errs []error
@@ -373,7 +447,7 @@ func createAndTestPodRepeatedly(workers, iterations int, scenario podScenario, p
 
 				// create the pod, capture the change events, then delete the pod
 				start := time.Now()
-				created, err := podClient.Create(context.TODO(), pod, metav1.CreateOptions{})
+				created, err := podClient.Create(ctx, pod, metav1.CreateOptions{})
 				framework.ExpectNoError(err, "failed to create pod")
 
 				ch := make(chan []watch.Event)
@@ -381,7 +455,7 @@ func createAndTestPodRepeatedly(workers, iterations int, scenario podScenario, p
 				go func() {
 					defer ginkgo.GinkgoRecover()
 					defer close(ch)
-					w, err := podClient.Watch(context.TODO(), metav1.ListOptions{
+					w, err := podClient.Watch(ctx, metav1.ListOptions{
 						ResourceVersion: created.ResourceVersion,
 						FieldSelector:   fmt.Sprintf("metadata.name=%s", pod.Name),
 					})
@@ -412,7 +486,7 @@ func createAndTestPodRepeatedly(workers, iterations int, scenario podScenario, p
 				case <-waitForWatch: // when the watch is established
 				}
 
-				verifier, scenario, err := scenario.Action(pod)
+				verifier, scenario, err := scenario.Action(ctx, pod)
 				framework.ExpectNoError(err, "failed to take action")
 
 				var (
@@ -483,7 +557,7 @@ func createAndTestPodRepeatedly(workers, iterations int, scenario podScenario, p
 
 type podScenario interface {
 	Pod(worker, attempt int) *v1.Pod
-	Action(*v1.Pod) (podScenarioVerifier, string, error)
+	Action(context.Context, *v1.Pod) (podScenarioVerifier, string, error)
 	IsLastEvent(event watch.Event) bool
 }
 
@@ -510,11 +584,11 @@ func (s podFastDeleteScenario) IsLastEvent(event watch.Event) bool {
 	return false
 }
 
-func (s podFastDeleteScenario) Action(pod *v1.Pod) (podScenarioVerifier, string, error) {
+func (s podFastDeleteScenario) Action(ctx context.Context, pod *v1.Pod) (podScenarioVerifier, string, error) {
 	t := time.Duration(rand.Intn(s.delayMs)) * time.Millisecond
 	scenario := fmt.Sprintf("t=%s", t)
 	time.Sleep(t)
-	return &podStartVerifier{pod: pod}, scenario, s.client.Delete(context.TODO(), pod.Name, metav1.DeleteOptions{})
+	return &podStartVerifier{pod: pod}, scenario, s.client.Delete(ctx, pod.Name, metav1.DeleteOptions{})
 }
 
 func (s podFastDeleteScenario) Pod(worker, attempt int) *v1.Pod {
@@ -651,13 +725,13 @@ func (v *podStartVerifier) Verify(event watch.Event) error {
 		return fmt.Errorf("pod %s on node %s had incorrect containers: %#v", pod.Name, pod.Spec.NodeName, pod.Status.ContainerStatuses)
 	}
 
-	if status := findContainerStatusInPod(pod, "blocked"); status != nil {
+	if status := e2epod.FindContainerStatusInPod(pod, "blocked"); status != nil {
 		if (status.Started != nil && *status.Started == true) || status.LastTerminationState.Terminated != nil || status.State.Waiting == nil {
 			return fmt.Errorf("pod %s on node %s should not have started the blocked container: %#v", pod.Name, pod.Spec.NodeName, status)
 		}
 	}
 
-	status := findContainerStatusInPod(pod, "fail")
+	status := e2epod.FindContainerStatusInPod(pod, "fail")
 	if status == nil {
 		return fmt.Errorf("pod %s on node %s had incorrect containers: %#v", pod.Name, pod.Spec.NodeName, pod.Status)
 	}
@@ -741,23 +815,3 @@ func (v *podStartVerifier) VerifyFinal(scenario string, total time.Duration) (*v
 	framework.Logf("Pod %s on node %s %s total=%s run=%s execute=%s", pod.Name, pod.Spec.NodeName, scenario, total, v.completeDuration, v.duration)
 	return pod, errs
 }
-
-// findContainerStatusInPod finds a container status by its name in the provided pod
-func findContainerStatusInPod(pod *v1.Pod, containerName string) *v1.ContainerStatus {
-	for _, container := range pod.Status.InitContainerStatuses {
-		if container.Name == containerName {
-			return &container
-		}
-	}
-	for _, container := range pod.Status.ContainerStatuses {
-		if container.Name == containerName {
-			return &container
-		}
-	}
-	for _, container := range pod.Status.EphemeralContainerStatuses {
-		if container.Name == containerName {
-			return &container
-		}
-	}
-	return nil
-}
