@@ -37,16 +37,16 @@ var _ = utils.SIGDescribe("Subpath", func() {
 		var err error
 		var privilegedSecurityContext bool = false
 
-		ginkgo.BeforeEach(func() {
+		ginkgo.BeforeEach(func(ctx context.Context) {
 			ginkgo.By("Setting up data")
 			secret := &v1.Secret{ObjectMeta: metav1.ObjectMeta{Name: "my-secret"}, Data: map[string][]byte{"secret-key": []byte("secret-value")}}
-			_, err = f.ClientSet.CoreV1().Secrets(f.Namespace.Name).Create(context.TODO(), secret, metav1.CreateOptions{})
+			_, err = f.ClientSet.CoreV1().Secrets(f.Namespace.Name).Create(ctx, secret, metav1.CreateOptions{})
 			if err != nil && !apierrors.IsAlreadyExists(err) {
 				framework.ExpectNoError(err, "while creating secret")
 			}
 
 			configmap := &v1.ConfigMap{ObjectMeta: metav1.ObjectMeta{Name: "my-configmap"}, Data: map[string]string{"configmap-key": "configmap-value"}}
-			_, err = f.ClientSet.CoreV1().ConfigMaps(f.Namespace.Name).Create(context.TODO(), configmap, metav1.CreateOptions{})
+			_, err = f.ClientSet.CoreV1().ConfigMaps(f.Namespace.Name).Create(ctx, configmap, metav1.CreateOptions{})
 			if err != nil && !apierrors.IsAlreadyExists(err) {
 				framework.ExpectNoError(err, "while creating configmap")
 			}
@@ -57,9 +57,9 @@ var _ = utils.SIGDescribe("Subpath", func() {
 		  Testname: SubPath: Reading content from a secret volume.
 		  Description: Containers in a pod can read content from a secret mounted volume which was configured with a subpath.
 		*/
-		framework.ConformanceIt("should support subpaths with secret pod", func() {
+		framework.ConformanceIt("should support subpaths with secret pod", func(ctx context.Context) {
 			pod := testsuites.SubpathTestPod(f, "secret-key", "secret", &v1.VolumeSource{Secret: &v1.SecretVolumeSource{SecretName: "my-secret"}}, privilegedSecurityContext)
-			testsuites.TestBasicSubpath(f, "secret-value", pod)
+			testsuites.TestBasicSubpath(ctx, f, "secret-value", pod)
 		})
 
 		/*
@@ -67,9 +67,9 @@ var _ = utils.SIGDescribe("Subpath", func() {
 		  Testname: SubPath: Reading content from a configmap volume.
 		  Description: Containers in a pod can read content from a configmap mounted volume which was configured with a subpath.
 		*/
-		framework.ConformanceIt("should support subpaths with configmap pod", func() {
+		framework.ConformanceIt("should support subpaths with configmap pod", func(ctx context.Context) {
 			pod := testsuites.SubpathTestPod(f, "configmap-key", "configmap", &v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "my-configmap"}}}, privilegedSecurityContext)
-			testsuites.TestBasicSubpath(f, "configmap-value", pod)
+			testsuites.TestBasicSubpath(ctx, f, "configmap-value", pod)
 		})
 
 		/*
@@ -77,11 +77,11 @@ var _ = utils.SIGDescribe("Subpath", func() {
 		  Testname: SubPath: Reading content from a configmap volume.
 		  Description: Containers in a pod can read content from a configmap mounted volume which was configured with a subpath and also using a mountpath that is a specific file.
 		*/
-		framework.ConformanceIt("should support subpaths with configmap pod with mountPath of existing file", func() {
+		framework.ConformanceIt("should support subpaths with configmap pod with mountPath of existing file", func(ctx context.Context) {
 			pod := testsuites.SubpathTestPod(f, "configmap-key", "configmap", &v1.VolumeSource{ConfigMap: &v1.ConfigMapVolumeSource{LocalObjectReference: v1.LocalObjectReference{Name: "my-configmap"}}}, privilegedSecurityContext)
 			file := "/etc/resolv.conf"
 			pod.Spec.Containers[0].VolumeMounts[0].MountPath = file
-			testsuites.TestBasicSubpathFile(f, "configmap-value", pod, file)
+			testsuites.TestBasicSubpathFile(ctx, f, "configmap-value", pod, file)
 		})
 
 		/*
@@ -89,13 +89,13 @@ var _ = utils.SIGDescribe("Subpath", func() {
 		  Testname: SubPath: Reading content from a downwardAPI volume.
 		  Description: Containers in a pod can read content from a downwardAPI mounted volume which was configured with a subpath.
 		*/
-		framework.ConformanceIt("should support subpaths with downward pod", func() {
+		framework.ConformanceIt("should support subpaths with downward pod", func(ctx context.Context) {
 			pod := testsuites.SubpathTestPod(f, "downward/podname", "downwardAPI", &v1.VolumeSource{
 				DownwardAPI: &v1.DownwardAPIVolumeSource{
 					Items: []v1.DownwardAPIVolumeFile{{Path: "downward/podname", FieldRef: &v1.ObjectFieldSelector{APIVersion: "v1", FieldPath: "metadata.name"}}},
 				},
 			}, privilegedSecurityContext)
-			testsuites.TestBasicSubpath(f, pod.Name, pod)
+			testsuites.TestBasicSubpath(ctx, f, pod.Name, pod)
 		})
 
 		/*
@@ -103,7 +103,7 @@ var _ = utils.SIGDescribe("Subpath", func() {
 		  Testname: SubPath: Reading content from a projected volume.
 		  Description: Containers in a pod can read content from a projected mounted volume which was configured with a subpath.
 		*/
-		framework.ConformanceIt("should support subpaths with projected pod", func() {
+		framework.ConformanceIt("should support subpaths with projected pod", func(ctx context.Context) {
 			pod := testsuites.SubpathTestPod(f, "projected/configmap-key", "projected", &v1.VolumeSource{
 				Projected: &v1.ProjectedVolumeSource{
 					Sources: []v1.VolumeProjection{
@@ -114,16 +114,16 @@ var _ = utils.SIGDescribe("Subpath", func() {
 					},
 				},
 			}, privilegedSecurityContext)
-			testsuites.TestBasicSubpath(f, "configmap-value", pod)
+			testsuites.TestBasicSubpath(ctx, f, "configmap-value", pod)
 		})
 
 	})
 
 	ginkgo.Context("Container restart", func() {
-		ginkgo.It("should verify that container can restart successfully after configmaps modified", func() {
+		ginkgo.It("should verify that container can restart successfully after configmaps modified", func(ctx context.Context) {
 			configmapToModify := &v1.ConfigMap{ObjectMeta: metav1.ObjectMeta{Name: "my-configmap-to-modify"}, Data: map[string]string{"configmap-key": "configmap-value"}}
 			configmapModified := &v1.ConfigMap{ObjectMeta: metav1.ObjectMeta{Name: "my-configmap-to-modify"}, Data: map[string]string{"configmap-key": "configmap-modified-value"}}
-			testsuites.TestPodContainerRestartWithConfigmapModified(f, configmapToModify, configmapModified)
+			testsuites.TestPodContainerRestartWithConfigmapModified(ctx, f, configmapToModify, configmapModified)
 		})
 	})
 })
