@@ -19,6 +19,7 @@ limitations under the License.
 package remote
 
 import (
+	"fmt"
 	"time"
 )
 
@@ -51,3 +52,25 @@ type TestSuite interface {
 	// * timeout is the test timeout.
 	RunTest(host, workspace, results, imageDesc, junitFilePrefix, testArgs, ginkgoArgs, systemSpecName, extraEnvs, runtimeConfig string, timeout time.Duration) (string, error)
 }
+
+var testSuites = make(map[string]TestSuite)
+
+func RegisterTestSuite(name string, suite TestSuite) {
+	testSuites[name] = suite
+}
+
+func GetTestSuiteKeys() []string {
+	var keys []string
+	for key := range testSuites {
+		keys = append(keys, key)
+	}
+	return keys
+}
+
+func GetTestSuite(name string) (TestSuite, error) {
+	suite, ok := testSuites[name]
+	if ok {
+		return suite, nil
+	}
+	return nil, fmt.Errorf("unable to find testsuite for %s", name)
+}
