@@ -41,12 +41,15 @@ const (
 
 var (
 	// env configs
-	GOROOT    string = os.Getenv("GOROOT")
-	GOOS      string = os.Getenv("GOOS")
-	KUBE_ROOT string = os.Getenv("KUBE_ROOT")
+	GOROOT                string = os.Getenv("GOROOT")
+	GOOS                  string = os.Getenv("GOOS")
+	KUBE_ROOT             string = os.Getenv("KUBE_ROOT")
+	ALL_STABILITY_CLASSES bool
 )
 
 func main() {
+
+	flag.BoolVar(&ALL_STABILITY_CLASSES, "allstabilityclasses", false, "use this flag to enable all stability classes")
 	flag.Parse()
 	if len(flag.Args()) < 1 {
 		fmt.Fprintf(os.Stderr, "USAGE: %s <DIR or FILE or '-'> [...]\n", os.Args[0])
@@ -86,6 +89,12 @@ func main() {
 	if len(stableMetrics) == 0 {
 		os.Exit(0)
 	}
+	for i, m := range stableMetrics {
+		if m.StabilityLevel == "" {
+			m.StabilityLevel = "ALPHA"
+		}
+		stableMetrics[i] = m
+	}
 	sort.Sort(byFQName(stableMetrics))
 	data, err := yaml.Marshal(stableMetrics)
 	if err != nil {
